-
O que é o Mariabackup?
-
Fazer backup e restaurar o MariaDB com o Mariabackup
-
Fazer backup e restaurar o MariaDB com o mysqldump
-
Fazer Backup e Restaurar o MariaDB com uma Solução de Backup de Banco de Dados
-
Resumo

MariaDB é um popular sistema de gerenciamento de banco de dados relacional (SGBDR) de código aberto, projetado para ser uma substituição direta do MySQL. Foi criado pelos desenvolvedores originais do MySQL após surgirem preocupações com sua aquisição pela Oracle Corporation.
O MariaDB possui alta compatibilidade com o MySQL e apresenta paridade binária idêntica nas bibliotecas, além de corresponder exatamente às APIs e aos comandos do MySQL. Isso torna mais fácil a migração de bancos de dados do MySQL para o MariaDB.
Se você está usando o MariaDB, é essencial saber como fazer backups do MariaDB e restaurá-los. Neste artigo, você aprenderá a fazer backup e restaurar o MariaDB com o Mariabackup e com os outros dois métodos. Em seguida, você pode se perguntar: o que é o Mariabackup?
O que é o Mariabackup?
O Mariabackup, derivado do Percona XtraBackup, é uma ferramenta de código aberto criada pela MariaDB que pode ser usada para realizar backups online de tabelas InnoDB, MyRocks, Aria e MyISAM em formato físico.
Opções:
| --aplicar-registro | Prepara um backup atual para a recuperação do MariaDB Server. |
| --apply-log-only | Executar apenas a fase de aplicação do log de reexecução. |
| --backup | Faz backup do MariaDB. |
| --binlog-info | Especifica a forma de recuperar as coordenadas do log binário do servidor. |
| --fechar-arquivos | Define se os manipuladores de arquivos devem ou não ser fechados. |
| --compress | Define a compressão do arquivo de backup. |
| --compress-chunk-size | Especifica o tamanho do buffer de trabalho para as threads de compactação. |
| --compress-threads | Especifica o número de threads de compactação. |
| --copiar-de-volta | Restaura o backup no diretório de dados. |
| --bancos de dados | Define os bancos de dados e as tabelas que deseja fazer backup. |
Observação: Acesse a página de opções do Mariabackup para saber mais.
Funcionalidades:
Configura uma réplica a partir de um backup.
Utiliza ferramentas de criptografia e compressão.
Restaura tabelas e partições individuais.
Suporta o método SST com o Cluster Glaera.
Suporta backup e restauração completos, parciais e incrementais.
Faz backup e restaura tabelas usando criptografia de dados em repouso, mecanismo de armazenamento MyRocks e compactação de páginas InnoDB.
Minimiza os bloqueios durante o backup e fornece suporte ideal para backup de todos os mecanismos de armazenamento do MariaDB Enterprise Backup.
Vantagens:
Código aberto e gratuito para uso.
Oferece um alto nível de consistência e integridade dos dados.
Fácil de configurar e usar, com documentação clara e uma interface amigável para o usuário.
Projetado especificamente para o MariaDB, é otimizado para esse sistema específico de gerenciamento de banco de dados.
Desvantagens:
Suporta apenas operações de backup e restauração para MariaDB.
Não suporta criptografia baseada em ferramentas de backup nem a opção de compactação.
Exige algum conhecimento de interfaces de linha de comando e procedimentos de backup.
Não suporta compactação nem criptografia de dados em repouso para capacidade de backup completo.
Não suporta backup parcial dos dados do MyRocks e o backup incremental armazenará uma cópia completa.
Pode não ser adequado para bancos de dados muito grandes ou para operações de backup que precisam ser realizadas com frequência, pois pode consumir uma quantidade significativa de recursos do sistema.
Tenha cuidado para não incluir erros de digitação ou usar opções de versões mais recentes do Mariabackup, pois o software ignora opções desconhecidas na linha de comando sem exibir uma mensagem de erro.
Instalar o Mariabackup
No Linux:
Instale com um gerenciador de pacotes e execute como root:
curl -LsS https://r.mariadb.com/downloads/mariadb_repo_setup | sudo bash
Instale com yum/dnf para RHEL, CentOS, Fedora e outras distribuições Linux semelhantes:
sudo yum install MariaDB-backup
Instale com apt-get para Debian, Ubuntu e outras distribuições Linux semelhantes:
sudo apt-get install mariadb-backup
Instalar com zip para SLES, OpenSUSE e outras distribuições Linux semelhantes:
sudo zypper install MariaDB-backup
No Windows:
1. Instale o pacote MSI do MariaDB.
2. Clique no arquivo mariadb-<major>.<minor>.<patch>.msi.
3. Clique em Próximo na página de boas-vindas e aceite o acordo de licença, clique em Próximo.
4. Na página Configuração personalizada, clique em Utilitários de backup para instalar.
5. Siga o assistente.
Fazer backup e restaurar o MariaDB com o Mariabackup
Fazer backup de todo o servidor de banco de dados:
$ mariabackup --backup --target-dir=/var/mariadb/backup/ --user=mariabackup --password=mypassword
Efetue um backup incremental (crie primeiro um backup completo):
$ mariabackup --backup --target-dir=/var/mariadb/inc1/ --incremental-basedir=/var/mariadb/backup/ --user=mariabackup --password=mypassword
Prepare cópias de segurança consistentes para recuperação:
$ mariabackup --prepare --target-dir=/var/mariadb/backup/
Restaurar o banco de dados completo:
a. Pare o processo do servidor e certifique-se de que o diretório datadir está vazio.
b. Execute –copy-back para manter os arquivos de backup originais ou –move-back para mover os dados para o diretório datadir, perdendo-se assim os arquivos originais.
$ mariabackup --copy-back --target-dir=/var/mariadb/backup/
c. Inicie o processo do servidor MariaDB.
Restaure as alterações no primeiro backup incremental e repita esta etapa para cada um dos demais com o MariaDB 10.2:
a. Prepare o backup completo da base.
$ mariabackup --prepare --target-dir=/var/mariadb/backup --incremental-dir=/var/mariadb/inc1
b. Sincronize a base com as alterações.
$ mariabackup --prepare -target-dir=/var/mariadb/backup --incremental-dir=/var/mariadb/inc1
c. Interrompa o processo do servidor e certifique-se de que o diretório datadir está vazio.
d. Execute –copy-back para manter os arquivos de backup originais ou –move-back para mover os dados para o diretório datadir, perdendo-se assim os arquivos originais.
$ mariabackup --copy-back --target-dir=/var/mariadb/backup/
Restaurar backup incremental com MariaDB até a versão 10.1:
a. Prepare o backup completo da base.
$ mariabackup --prepare --apply-log-only --target-dir=/var/mariadb/backup
b. Aplicar os acréscimos à base:
$ mariabackup --prepare --apply-log-only --target-dir=/var/mariadb/backup --incremental-dir=/var/mariadb/inc1
c. Interrompa o processo do servidor e certifique-se de que o diretório datadir esteja vazio.
d. Execute –copy-back para manter os arquivos de backup originais ou –move-back para mover os dados para o diretório datadir, perdendo-se assim os arquivos originais.
$ mariabackup --copy-back --target-dir=/var/mariadb/backup/
Fazer backup e restaurar o MariaDB com o mysqldump
O mysqldump é uma ferramenta integrada do MariaDB para fazer backup de um ou mais bancos de dados, gerando dumps em formatos como CSV, outros formatos de texto delimitado ou XML, podendo também ser usado para fazer backup e restaurar o MySQL.
Exportar todos os bancos de dados MariaDB:
mysqldump -u xx -p -x -A > /data/backup/dbs.sql
Descarregar várias bases de dados e todas as bases de dados:
shell> mysqldump --databases db_name1 [db_name2 ...] > my_databases.sql shell> mysqldump --all-databases > all_databases.sql
Fazer backup de todo o banco de dados:
shell> mysqldump db_name > backup-file.sql
Backup de um único banco de dados:
mysqldump --user=xx --password --lock-tables --databases db1 > /data/backup/db1.sql
Fazer backup de uma tabela:
mysqldump --user=xx --password --lock-tables db1 table1 > /data/backup/db1_table1.sql
Restaurar um backup:
mysql -u root -p < backup-file.sql
Fazer Backup e Restaurar o MariaDB com uma Solução de Backup de Banco de Dados
De qualquer forma, os processos de backup e restauração do MariaDB estão longe de ser intuitivos e fáceis de usar para um iniciante. Experimente o Vinchin Backup & Recovery, compatível com 12 plataformas de virtualização, tais como VMware, Hyper-V, Xen, RHEV/oVirt, etc., 2 servidores físicos, NAS e 6 bancos de dados, incluindo Oracle DB, MySQL, SQL Server, PostgreSQL, Postgres Pro e MariaDB.

Você pode automatizar o backup do banco de dados com agendamentos personalizados e escolher, com um único clique, entre backups completos, diferenciais, incrementais e de log (variam conforme o banco de dados).
Você pode ativar a desduplicação e a compactação de dados para reduzir o tamanho total do backup e ativar a criptografia de dados com o padrão AES-256 para segurança.
Restaure o MariaDB para o banco de dados original ou para um novo destino e prepare uma cópia de backup fora do local em um local remoto.
Processo simples de backup do MariaDB:
1. Acesse Backup físico > Backup de banco de dados > Backup e selecione o agente de backup de banco de dados instalado e a origem do backup.
2. Selecione o nó de backup e o armazenamento nesse nó para a tarefa.
3. Especifique as estratégias de backup conforme necessário.

4. Confirme e envie.
Processo Simples de Recuperação do MariaDB:
1. Acesse Backup Físico > Backup de Banco de Dados > Restaurar e selecione o recurso de recuperação a partir dos backups de banco de dados.
2. Selecione a instância de destino.
3. Restaure para o local original ou para um novo destino e especifique as estratégias de restauração.

4. Confirme e envie.
Resumo
Você pode fazer backup e restaurar o MariaDB com o Mariabackup e o Mysqldump, mas essas ferramentas não oferecem uma interface gráfica intuitiva nem a variedade de opções de backup disponíveis no Vinchin Backup & Recovery, uma solução profissional para backup de bancos de dados. A ferramenta automatiza o backup e a recuperação de dados, além de contar com tecnologias avançadas de proteção contra malware, garantindo uma proteção abrangente para seus dados do MariaDB.
Partilhar em: